@@ -75,7 +75,7 @@ def validate(
         )
     except Exception as e:
         console.print(f"Failed validation. Saving log to:\n\t{log_filepath}")
-        logger.error(e)
+        logger.error(e, exc_info=True)
         return
 
     with open(results_path, "w") as f:
