@@ -15,6 +15,7 @@ logger = logging.getLogger(__name__)
 
 
 def run_BuiltinCallable(target: Any, builtin: BuiltinCallable) -> Any:
+    """Runs a BuiltinCallable on an arbitrary value."""
     return builtin.resolved_function(
         target,
         **builtin.args,
@@ -22,10 +23,19 @@ def run_BuiltinCallable(target: Any, builtin: BuiltinCallable) -> Any:
 
 
 def run_ValidationStep(filepath: str, step: ValidationStep) -> ValidationResult:
+    """Runs a single validation step.
+
+    Args:
+        filepath (str): filepath of data to validate.
+        step (ValidationStep): validation step to run.
+
+    Returns:
+        result (ValidationResult): result of the validation
+    """
     if step.processor:
         processed = run_BuiltinCallable(
             filepath,
-            step.processor,
+            step.processor.builtin,
         )  # type: Union[Any, str]
     else:
         processed = filepath
@@ -33,18 +43,26 @@ def run_ValidationStep(filepath: str, step: ValidationStep) -> ValidationResult:
     return ValidationResult(
         filepath=filepath,
         results=[
-            run_BuiltinCallable(processed, validator) for validator in step.validators
+            run_BuiltinCallable(processed, validator.builtin)
+            for validator in step.validators
         ],
     )
 
 
 def run_validation(
-    file_list: List[str], validation_steps: List[Dict[str, Any]]
+    file_list: List[str], validation_steps: List[ValidationStep]
 ) -> List[ValidationResult]:
-    loaded = map(load_ValidationStep, validation_steps)
+    """Validates a list of files.
 
+    Args:
+        file_list (:obj:`list` of :obj:`str`): List of filepaths to validate.
+        validation_steps: List of validation steps to run.
+
+    Returns:
+        results: List of validation results.
+    """
     results = []
-    for validation_step in loaded:
+    for validation_step in validation_steps:
         for filepath in file_list:
             if path_matches_pattern(filepath, validation_step.path_suffix):
                 results.append(
